# Anyscale

This package contains the command line interface and the sdk for the Anyscale platform.

View Anyscale docs [here](https://docs.anyscale.com)
View CLI docs [here](https://docs.anyscale.com/reference/cli)
View SDK docs [here](https://docs.anyscale.com/reference/python-sdk/api)
